//
//CycIF script for generating registered images
//Jerry Lin 2015/09/21
//
// for GE Cytell imaging
// 96 well format with 12 fields measured
// 4 channel (DAPI, FITC, Cy3, Cy5)
// Usage: arrange your CycIF images in the same folder and re-name each subfolder by the CycIF cycle
//      : 1st, 2nd, 3rd, 4th, 5th, 6th, 7th, 8th, 9th, 10th
//      : run the macro within ImageJ and select the folder where all CycIF images are located
//      : The script will generate the measurement files for each fields
//

path = getDirectory("Select the image directory");

row = newArray(" ","A","B","C","D","E","F","G","H");
col =newArray("00","01","02","03","04","05","06","07","08","09","10","11","12");
fl = newArray("00","01","02","03","04","05","06","07","08","09","10","11","12");

start = getTime;

while (nImages>0) {
          selectImage(nImages);
          close();
}

if (isOpen("ROI Manager")) {
      selectWindow("ROI Manager");
      run("Close");
}

setBatchMode(true);

for (r=2;r<8;r++)		//row array
{
for (c=2;c<12;c++)		//column array
{
for (f=1;f<13;f++)		//filed
{

run("Image Sequence...", "open=["+path+"1st\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Image Sequence...", "open=["+path+"2nd\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Image Sequence...", "open=["+path+"3rd\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Image Sequence...", "open=["+path+"4th\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Image Sequence...", "open=["+path+"5th\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Image Sequence...", "open=["+path+"6th\\B - 02(fld 01 wv Cy3 - Cy3).tif] file=["+row[r]+" - "+col[c]+"(fld "+fl[f]+"] sort");
run("Stack to Images");

run("Images to Stack", "name=DAPI title=DAPI");
run("Subtract Background...", "rolling=50 stack");

run("Images to Stack", "name=FITC title=FITC");
run("Subtract Background...", "rolling=50 stack");

run("Images to Stack", "name=Cy5 title=Cy5");
run("Subtract Background...", "rolling=50 stack");

run("Images to Stack", "name=Cy3 title=Cy3");
run("Subtract Background...", "rolling=50 stack");


run("MultiStackReg", "stack_1=DAPI action_1=Align file_1="+path+"reg1.txt stack_2=None action_2=Ignore file_2=[] transformation=[Rigid Body] save");

run("MultiStackReg", "stack_1=FITC action_1=[Load Transformation File] file_1="+path+"reg1.txt stack_2=None action_2=Ignore file_2=[] transformation=[Rigid Body]");

run("MultiStackReg", "stack_1=Cy5 action_1=[Load Transformation File] file_1="+path+"reg1.txt stack_2=None action_2=Ignore file_2=[] transformation=[Rigid Body]");

run("MultiStackReg", "stack_1=Cy3 action_1=[Load Transformation File] file_1="+path+"reg1.txt stack_2=None action_2=Ignore file_2=[] transformation=[Rigid Body]");

selectWindow("DAPI");
run("Stack to Images");
selectWindow("Cy3");
run("Stack to Images");
selectWindow("Cy5");
run("Stack to Images");
selectWindow("FITC");
run("Stack to Images");

run("Images to Stack", "name="+row[r]+col[c]+"_fld"+f+" title=[] use");

run("Stack to Image5D", "3rd=ch 4th=z 3rd_dimension_size=24 4th_dimension_size=1");

run("Save Image5D", "save="+path+row[r]+col[c]+"_fld"+fl[f]+".tif");

run("Close");

print("Well ",row[r],"-",col[c],"-",f," finisehd:",(getTime-start)/1000);
} //for f
} //for c
} //for r

setBatchMode(false);

